@@ -42,6 +42,7 @@ class enigma_driver_gnupg extends enigma_driver
         $homedir = $this->rc->config->get('enigma_pgp_homedir', INSTALL_PATH . 'plugins/enigma/home');
         $debug   = $this->rc->config->get('enigma_debug');
         $binary  = $this->rc->config->get('enigma_pgp_binary');
+        $agent   = $this->rc->config->get('enigma_pgp_agent');
 
         if (!$homedir) {
             return new enigma_error(enigma_error::INTERNAL,
@@ -84,6 +85,9 @@ class enigma_driver_gnupg extends enigma_driver
         if ($binary) {
             $options['binary'] = $binary;
         }
+        if ($agent) {
+            $options['agent'] = $agent;
+        }
 
         // Create Crypt_GPG object
         try {
@@ -277,6 +281,8 @@ class enigma_driver_gnupg extends enigma_driver
      */
     public function gen_key($data)
     {
+        require_once 'Crypt/GPG/KeyGenerator.php';
+
         try {
             $debug  = $this->rc->config->get('enigma_debug');
             $keygen = new Crypt_GPG_KeyGenerator(array(
@@ -405,17 +411,20 @@ class enigma_driver_gnupg extends enigma_driver
      */
     protected function parse_signature($sig)
     {
-        $user = $sig->getUserId();
-
         $data = new enigma_signature();
+
         $data->id          = $sig->getId();
         $data->valid       = $sig->isValid();
         $data->fingerprint = $sig->getKeyFingerprint();
         $data->created     = $sig->getCreationDate();
         $data->expires     = $sig->getExpirationDate();
-        $data->name        = $user->getName();
-        $data->comment     = $user->getComment();
-        $data->email       = $user->getEmail();
+
+        // In case of ERRSIG user may not be set
+        if ($user = $sig->getUserId()) {
+            $data->name    = $user->getName();
+            $data->comment = $user->getComment();
+            $data->email   = $user->getEmail();
+        }
 
         return $data;
     }
